"Xarchie.archieHost:	archie.sura.net",
"Xarchie.searchType:	exact",
"Xarchie.sortType:	default",
"Xarchie.maxHits:	99",
"Xarchie.offset:		0",
"Xarchie.timeout:	4",
"Xarchie.retries:	3",
"Xarchie.niceLevel:	0",
"Xarchie.ftpDir:		.",
"Xarchie.ftpMode:	binary",
"Xarchie.saveFormatOneLine:	False",
"Xarchie.debugLevel:	0",
"Xarchie.expert:		False",
"Xarchie.widgets: \
	toplevel			Paned		outerPaned \
\
	outerPaned			Form		buttonForm \
	outerPaned.buttonForm		Command		quitButton \
	outerPaned.buttonForm		Command		queryButton \
	outerPaned.buttonForm		Command		abortButton \
	outerPaned.buttonForm		Command		saveButton \
	outerPaned.buttonForm		Command		ftpButton \
	outerPaned.buttonForm		MenuButton	searchButton \
	outerPaned.buttonForm		MenuButton	sortButton \
	outerPaned.buttonForm		MenuButton	niceButton \
	outerPaned.buttonForm		Command		settingsButton \
	outerPaned.buttonForm		Label		statusLabel \
	outerPaned.buttonForm		AsciiText	statusText \
\
	outerPaned			Paned		innerPaned \
	outerPaned.innerPaned		Viewport	hostView \
	outerPaned.innerPaned.hostView	List		hostList \
	outerPaned.innerPaned		Viewport	locationView \
	outerPaned.innerPaned.locationView List		locationList \
	outerPaned.innerPaned		Viewport	fileView \
	outerPaned.innerPaned.fileView	List		fileList \
\
	outerPaned		Form			stringForm \
	outerPaned.stringForm	Label			searchLabel \
	outerPaned.stringForm	AsciiText		searchText \
	outerPaned.stringForm	Label			hostLabel \
	outerPaned.stringForm	AsciiText		hostText \
	outerPaned.stringForm	Label			locationLabel \
	outerPaned.stringForm	AsciiText		locationText \
	outerPaned.stringForm	Label			fileLabel \
	outerPaned.stringForm	AsciiText		fileText \
	outerPaned.stringForm	Label			sizeLabel \
	outerPaned.stringForm	AsciiText		sizeText \
	outerPaned.stringForm	Label			modesLabel \
	outerPaned.stringForm	AsciiText		modesText \
	outerPaned.stringForm	Label			dateLabel \
	outerPaned.stringForm	AsciiText		dateText ",
"Xarchie.menus:\
	outerPaned.buttonForm.searchButton EzMenu	searchNowMenu \
	outerPaned.buttonForm.sortButton EzMenu		sortNowMenu \
	outerPaned.buttonForm.niceButton EzMenu		niceNowMenu",
"Xarchie.settingsWidgets:\
	toplevel			TopLevelShell	settingsShell \
	settingsShell			Form		settingsForm \
	settingsShell.settingsForm	Command		doneButton \
	settingsShell.settingsForm	Command		applyButton \
	settingsShell.settingsForm	Command		defaultButton \
\
	settingsShell.settingsForm	MenuButton	setSearchButton \
	settingsShell.settingsForm	EzMenu		searchMenu \
	settingsShell.settingsForm	Label		searchLabel \
	settingsShell.settingsForm	MenuButton	setSortButton \
	settingsShell.settingsForm	EzMenu		sortMenu \
	settingsShell.settingsForm	Label		sortLabel \
	settingsShell.settingsForm	MenuButton	hostButton \
	settingsShell.settingsForm	EzMenu		hostMenu \
	settingsShell.settingsForm	AsciiText	setHostText \
	settingsShell.settingsForm	Label		maxHitsLabel \
	settingsShell.settingsForm	AsciiText	maxHitsText \
	settingsShell.settingsForm	Label		timeoutLabel \
	settingsShell.settingsForm	AsciiText	timeoutText \
	settingsShell.settingsForm	Label		retriesLabel \
	settingsShell.settingsForm	AsciiText	retriesText \
	settingsShell.settingsForm	MenuButton	setNiceButton \
	settingsShell.settingsForm	EzMenu		niceMenu \
	settingsShell.settingsForm	AsciiText	niceText \
	settingsShell.settingsForm	Label		ftpDirLabel \
	settingsShell.settingsForm	AsciiText	ftpDirText \
	settingsShell.settingsForm	Label		ftpTypeLabel \
	settingsShell.settingsForm	AsciiText	ftpTypeText",
"Xarchie*input:			True",
"Xarchie*Viewport*allowVert:		True",
"Xarchie*Viewport*allowHoriz:		False",
"Xarchie*Viewport*forceBars:		True",
"Xarchie*Viewport*preferredPaneSize:	160",
"Xarchie*Viewport.vertical.width:	15",
"Xarchie*List*font:		fixed",
"Xarchie*List*verticalList:	True",
"Xarchie*List*defaultColumns:	1",
"Xarchie*List*forceColumns:	True",
"Xarchie*List*height:		150",
"Xarchie*Grip*height:		5",
"Xarchie*Grip*width:		5",
"Xarchie*Label.borderWidth:	0",
"Xarchie*Label.internalWidth:	0",
"	",
"Xarchie*Text*borderWidth:	1",
"Xarchie*Text*font:		fixed",
"Xarchie*Text*Scrollbar.thickness: 5",
"Xarchie*Text*editType:		edit",
"Xarchie*Text.scrollHorizontal:	whenNeeded",
"Xarchie*Text*displayCaret:	False",
"Xarchie*Text*translations:#override\\n\
	<Key>Return:	no-op() \\n\
	<Enter>:	display-caret(True) \\n\
	<Leave>:	display-caret(False) \\n",
"Xarchie*outerPaned.orientation:	vertical",
"Xarchie*buttonForm.min: 50",
"Xarchie*buttonForm.max: 50",
"Xarchie*buttonForm.showGrip: False",
"Xarchie*buttonForm*quitButton.label:	Quit",
"Xarchie*buttonForm*quitButton.translations:#override\\n\
	Shift<Btn1Down>,<Btn1Up>:	quit(always) \\n\
	<Btn1Down>,<Btn1Up>:		quit() \\n",
"Xarchie*buttonForm*queryButton.label:		Query",
"Xarchie*buttonForm*queryButton.fromHoriz:	quitButton",
"Xarchie*buttonForm*queryButton.translations:#override\\n\
	<Btn1Down>,<Btn1Up>:	query() \\n",
"Xarchie*buttonForm*abortButton.label:		Abort",
"Xarchie*buttonForm*abortButton.fromHoriz:	queryButton",
"Xarchie*buttonForm*abortButton.translations:#override\\n\
	<Btn1Down>,<Btn1Up>:	abort() \\n",
"Xarchie*buttonForm*saveButton.label:		Save",
"Xarchie*buttonForm*saveButton.fromHoriz:	abortButton",
"Xarchie*buttonForm*saveButton.translations:#override\\n\
	Shift<Btn1Down>,<Btn1Up>:	save-to-file(\"%s.lst\") \\n\
	<Btn1Down>,<Btn1Up>:		save-to-file() \\n",
"Xarchie*buttonForm*ftpButton.label:		Ftp",
"Xarchie*buttonForm*ftpButton.fromHoriz:		saveButton",
"Xarchie*buttonForm*ftpButton.translations:#override\\n\
	<Btn1Down>,<Btn1Up>:	ftp() \\n",
"Xarchie*buttonForm*searchButton.label:		Search Type",
"Xarchie*buttonForm*searchButton.menuName:	searchNowMenu",
"Xarchie*buttonForm*searchButton.fromHoriz:	ftpButton",
"Xarchie*buttonForm*sortButton.label:		Sort Type",
"Xarchie*buttonForm*sortButton.menuName:		sortNowMenu",
"Xarchie*buttonForm*sortButton.fromHoriz:	searchButton",
"Xarchie*buttonForm*niceButton.label:		Nice Level",
"Xarchie*buttonForm*niceButton.menuName:		niceNowMenu",
"Xarchie*buttonForm*niceButton.fromHoriz:	sortButton",
"Xarchie*buttonForm*settingsButton.label:	Settings...",
"Xarchie*buttonForm*settingsButton.fromHoriz:	niceButton",
"Xarchie*buttonForm*settingsButton.translations:#override\\n\
	<Btn1Down>,<Btn1Up>:	settings() \\n",
"Xarchie*buttonForm*statusLabel.label:		Status:",
"Xarchie*buttonForm*statusLabel.fromVert:	quitButton",
"Xarchie*buttonForm*statusText.fromHoriz:	statusLabel",
"Xarchie*buttonForm*statusText.fromVert:		quitButton",
"Xarchie*buttonForm*statusText*width:		410",
"Xarchie*buttonForm*statusText*editType:		read",
"Xarchie*buttonForm*statusText.borderWidth:	0",
"Xarchie*buttonForm*statusText*scrollHorizontal:	never",
"Xarchie*buttonForm*statusText*translations:#override\\n",
"Xarchie*innerPaned.orientation:	horizontal",
"Xarchie*innerPaned.showGrip: False",
"Xarchie*stringForm.min: 120",
"Xarchie*stringForm.max: 120",
"Xarchie*stringForm*Label.justify:	left",
"Xarchie*stringForm*Label.font:		fixed",
"Xarchie*stringForm*AsciiSrc.editType: 	read",
"Xarchie*stringForm*searchLabel.label:		Search Term:",
"Xarchie*stringForm*searchLabel.font:		*fixed*bold*",
"Xarchie*stringForm*searchText*width:		375",
"Xarchie*stringForm*searchText.fromHoriz:	searchLabel",
"Xarchie*stringForm*searchText*editType: 	edit",
"Xarchie*stringForm*searchText*translations:#override\\n\
	<Enter>:	display-caret(True) \\n\
	<Leave>:	display-caret(False) \\n\
	<Key>Return:	query() \\n",
"Xarchie*stringForm*hostLabel.label:	Host:",
"Xarchie*stringForm*hostLabel.fromVert:	searchLabel",
"Xarchie*stringForm*hostText.fromVert:	searchLabel",
"Xarchie*stringForm*hostText.fromHoriz:	hostLabel",
"Xarchie*stringForm*hostText.width:	429",
"Xarchie*stringForm*locationLabel.label:		Location:",
"Xarchie*stringForm*locationLabel.fromVert:	hostLabel",
"Xarchie*stringForm*locationText.fromHoriz:	locationLabel",
"Xarchie*stringForm*locationText.fromVert:	hostLabel",
"Xarchie*stringForm*locationText.width:		405",
"Xarchie*stringForm*fileLabel.label:	File:",
"Xarchie*stringForm*fileLabel.fromVert:	locationLabel",
"Xarchie*stringForm*fileText.fromHoriz:	fileLabel",
"Xarchie*stringForm*fileText.fromVert:	locationLabel",
"Xarchie*stringForm*fileText.width:	429",
"Xarchie*stringForm*sizeLabel.label:	Size:",
"Xarchie*stringForm*sizeLabel.fromVert:	fileLabel",
"Xarchie*stringForm*sizeText.fromHoriz:	sizeLabel",
"Xarchie*stringForm*sizeText.fromVert:	fileLabel",
"Xarchie*stringForm*sizeText*width:	112",
"Xarchie*stringForm*modesLabel.label:	Mode:",
"Xarchie*stringForm*modesLabel.fromHoriz:sizeText",
"Xarchie*stringForm*modesLabel.fromVert:	fileLabel",
"Xarchie*stringForm*modesText.fromHoriz:	modesLabel",
"Xarchie*stringForm*modesText.fromVert:	fileLabel",
"Xarchie*stringForm*modesText*width:	112",
"Xarchie*stringForm*dateLabel.label:	Date:",
"Xarchie*stringForm*dateLabel.fromHoriz:	modesText",
"Xarchie*stringForm*dateLabel.fromVert:	fileLabel",
"Xarchie*stringForm*dateText.fromHoriz:	dateLabel",
"Xarchie*stringForm*dateText.fromVert:	fileLabel",
"Xarchie*stringForm*dateText*width:	125",
"Xarchie*settingsForm*Text*borderWidth:		0",
"Xarchie*settingsForm*Label*resizable:		True",
"Xarchie*settingsShell.title:			Xarchie Settings Panel",
"Xarchie*settingsForm*doneButton.label:		Done",
"Xarchie*settingsForm*doneButton.translations:#override\\n\
	<Btn1Down>,<Btn1Up>:	done-settings() \\n",
"Xarchie*settingsForm*applyButton.label:		Apply",
"Xarchie*settingsForm*applyButton.fromHoriz:	doneButton",
"Xarchie*settingsForm*applyButton.translations:#override\\n\
	<Btn1Down>,<Btn1Up>:	apply-settings() \\n",
"Xarchie*settingsForm*defaultButton.label:	Default",
"Xarchie*settingsForm*defaultButton.fromHoriz:	applyButton",
"Xarchie*settingsForm*defaultButton.translations:#override\\n\
	<Btn1Down>,<Btn1Up>:	default-settings() \\n",
"Xarchie*settingsForm*setSearchButton.label:	Search Mode:",
"Xarchie*settingsForm*setSearchButton.menuName:	searchMenu",
"Xarchie*settingsForm*setSearchButton.fromVert:	applyButton",
"Xarchie*settingsForm*setSearchButton.vertDistance:	10",
"Xarchie*settingsForm*searchLabel.fromVert:	applyButton",
"Xarchie*settingsForm*searchLabel.vertDistance:	10",
"Xarchie*settingsForm*searchLabel.fromHoriz:	setSearchButton",
"Xarchie*settingsForm*searchLabel.font:		fixed",
"Xarchie*settingsForm*setSortButton.label:	Sort Mode:",
"Xarchie*settingsForm*setSortButton.menuName:	sortMenu",
"Xarchie*settingsForm*setSortButton.fromVert:	setSearchButton",
"Xarchie*settingsForm*sortLabel.fromVert:	setSearchButton",
"Xarchie*settingsForm*sortLabel.fromHoriz:	setSortButton",
"Xarchie*settingsForm*sortLabel.font:		fixed",
"Xarchie*settingsForm*hostButton.label:		Host:",
"Xarchie*settingsForm*hostButton.menuName:	hostMenu",
"Xarchie*settingsForm*hostButton.fromVert:	setSortButton",
"Xarchie*settingsForm*setHostText.fromVert:	setSortButton",
"Xarchie*settingsForm*setHostText.fromHoriz:	hostButton",
"Xarchie*settingsForm*setHostText*width:		200",
"Xarchie*settingsForm*maxHitsLabel.label:	Max Hits:",
"Xarchie*settingsForm*maxHitsLabel.fromVert:	hostButton",
"Xarchie*settingsForm*maxHitsText.fromVert:	hostButton",
"Xarchie*settingsForm*maxHitsText.fromHoriz:	maxHitsLabel",
"Xarchie*settingsForm*timeoutLabel.label:	Initial Timeout:",
"Xarchie*settingsForm*timeoutLabel.fromVert:	maxHitsLabel",
"Xarchie*settingsForm*timeoutText.fromVert:	maxHitsLabel",
"Xarchie*settingsForm*timeoutText.fromHoriz:	timeoutLabel",
"Xarchie*settingsForm*retriesLabel.label:	Retries:",
"Xarchie*settingsForm*retriesLabel.fromVert:	timeoutLabel",
"Xarchie*settingsForm*retriesText.fromVert:	timeoutLabel",
"Xarchie*settingsForm*retriesText.fromHoriz:	retriesLabel",
"Xarchie*settingsForm*setNiceButton.label:	Nice Level:",
"Xarchie*settingsForm*setNiceButton.menuName:	niceMenu",
"Xarchie*settingsForm*setNiceButton.fromVert:	retriesLabel",
"Xarchie*settingsForm*niceText.fromVert:		retriesLabel",
"Xarchie*settingsForm*niceText.fromHoriz:	setNiceButton",
"Xarchie*settingsForm*ftpDirLabel.label:		Local Ftp Directory:",
"Xarchie*settingsForm*ftpDirLabel.fromVert:	setNiceButton",
"Xarchie*settingsForm*ftpDirText.fromVert:	setNiceButton",
"Xarchie*settingsForm*ftpDirText.fromHoriz:	ftpDirLabel",
"Xarchie*settingsForm*ftpTypeLabel.label:	Ftp Transfer Type:",
"Xarchie*settingsForm*ftpTypeLabel.fromVert:	ftpDirLabel",
"Xarchie*settingsForm*ftpTypeText.fromVert:	ftpDirLabel",
"Xarchie*settingsForm*ftpTypeText.fromHoriz:	ftpTypeLabel",
"Xarchie*searchMenu.label:			Search Mode",
"Xarchie*searchMenu.menu:\
	(line) \
	(item \"Exact\"		(action \"set-search-type(exact)\")) \
	(item \"Substr\"		(action \"set-search-type(substr)\")) \
	(item \"Subcase\"		(action \"set-search-type(subcase)\")) \
	(item \"Regexp\"		(action \"set-search-type(regexp)\")) \
	(item \"ExactSubstr\"	(action \"set-search-type(exactSubstr)\")) \
	(item \"ExactSubcase\"	(action \"set-search-type(exactSubcase)\")) \
	(item \"ExactRegexp\"	(action \"set-search-type(exactRegexp)\"))",
"Xarchie*sortMenu.label:		Sort Mode",
"Xarchie*sortMenu.menu:\
	(line) \
	(item \"Default\"		(action \"set-sort-type(default)\")) \
	(item \"Invdate\"		(action \"set-sort-type(invdate)\"))",
"Xarchie*hostMenu.label:		Archie Hosts",
"Xarchie*hostMenu.menu:\
   (line) \
   (item \"archie.sura.net\"	(action \"set-host(archie.sura.net)\")) \
   (item \"archie.mcgill.ca\"	(action \"set-host(archie.mcgill.ca)\")) \
   (item \"archie.funet.fi\"	(action \"set-host(archie.funet.fi)\")) \
   (item \"archie.au\"		(action \"set-host(archie.au)\")) \
   (item \"archie.doc.ic.ac.uk\"	(action \"set-host(archie.doc.ic.ac.uk)\")) \
   (item \"cs.huji.ac.il\"	(action \"set-host(cs.huji.ac.il)\"))",
"Xarchie*niceMenu.label:		Nice Levels",
"Xarchie*niceMenu.menu:\
	(line) \
	(item \"Default\"		(action \"set-nice-level(0)\")) \
	(item \"Nice\"		(action \"set-nice-level(500)\")) \
	(item \"Nicer\"		(action \"set-nice-level(1000)\")) \
	(item \"Very Nice\"	(action \"set-nice-level(5000)\")) \
	(item \"Extremely Nice\"	(action \"set-nice-level(10000)\")) \
	(item \"Nicest\"		(action \"set-nice-level(32765)\"))",
"Xarchie*searchNowMenu.label:			Search Mode",
"Xarchie*searchNowMenu.menu:\
	(line) \
	(item \"Exact\"		(action \"set-search-type-now(exact)\")) \
	(item \"Substr\"		(action \"set-search-type-now(substr)\")) \
	(item \"Subcase\"		(action \"set-search-type-now(subcase)\")) \
	(item \"Regexp\"		(action \"set-search-type-now(regexp)\")) \
	(item \"ExactSubstr\"	(action \"set-search-type-now(exactSubstr)\")) \
	(item \"ExactSubcase\"	(action \"set-search-type-now(exactSubcase)\")) \
	(item \"ExactRegexp\"	(action \"set-search-type-now(exactRegexp)\"))",
"Xarchie*sortNowMenu.label:		Sort Mode",
"Xarchie*sortNowMenu.menu:\
	(line) \
	(item \"Default\"		(action \"set-sort-type-now(default)\")) \
	(item \"Invdate\"		(action \"set-sort-type-now(invdate)\"))",
"Xarchie*niceNowMenu.label:		Nice Levels",
"Xarchie*niceNowMenu.menu:\
   (line) \
	(item \"Default\"		(action \"set-nice-level-now(0)\")) \
	(item \"Nice\"		(action \"set-nice-level-now(500)\")) \
	(item \"Nicer\"		(action \"set-nice-level-now(1000)\")) \
	(item \"Very Nice\"	(action \"set-nice-level-now(5000)\")) \
	(item \"Extremely Nice\"	(action \"set-nice-level-now(10000)\")) \
	(item \"Nicest\"		(action \"set-nice-level-now(32765)\"))",
"Xarchie*allowShellResize:		True",
"Xarchie*Dialog*Label.resizable:		True",
"Xarchie*Dialog*Text*scrollHorizontal:	never",
"Xarchie*Dialog.icon:			xlogo32",
"Xarchie*alertDialog*okButton.label:	Ok",
"Xarchie*confirmDialog*yesButton.label:	Yes",
"Xarchie*confirmDialog*noButton.label:	No",
"Xarchie*dialogDialog*okButton.label:	Ok",
"Xarchie*dialogDialog*cancelButton.label:Cancel",
"Xarchie*dialogDialog.value*translations:#override\\n\
	<Key>Return:	dialog-ok() \\n\
	<Enter>:	display-caret(True) \\n\
	<Leave>:	display-caret(False) \\n",
